@@ -253,15 +253,19 @@ class DAField(DAObject):
 
     # variable_name_guess is the placeholder label for the field
     variable_name_guess = self.variable.replace('_', ' ').capitalize()
+    self.variable_name_guess = variable_name_guess
+
     if self.variable.endswith('_date'):
       self.field_type_guess = 'date'
-      self.variable_name_guess = 'Date of ' + self.variable[:-5].replace('_', ' ')
+      self.variable_name_guess = f"Date of {variable_name_guess[:-5]}"
+    elif self.variable.endswith('_amount'):
+        self.field_type_guess = 'currency'
+    elif self.variable.endswith('_value'):
+        self.field_type_guess = 'currency'
     elif self.variable.endswith('.signature'):
       self.field_type_guess = "signature"
-      self.variable_name_guess = variable_name_guess
     else:
       self.field_type_guess = 'text'
-      self.variable_name_guess = variable_name_guess
 
   def fill_in_pdf_attributes(self, pdf_field_tuple):
     """Let's guess the type of each field from the name / info from PDF"""
@@ -290,6 +294,10 @@ class DAField(DAObject):
         self.field_type_guess = "signature"
     elif self.maxlength > 100:
         self.field_type_guess = 'area'
+    elif self.variable.endswith('_amount'):
+        self.field_type_guess = 'currency'
+    elif self.variable.endswith('_value'):
+        self.field_type_guess = 'currency'
     else:
         self.field_type_guess = 'text'
     
@@ -592,11 +600,11 @@ confirm: True
     all_columns = ''
     settable_list = ''
     for att, disp_and_set in self.attribute_map.items():
-      all_columns += '  - {0}: |\n'.format(att)
+      all_columns += '  - {0}: |\n'.format(att.capitalize().replace('_', ' '))
       all_columns += '      row_item.{0} if defined("row_item.{1}") else ""\n'.format( disp_and_set[0], disp_and_set[1])
       settable_list += '  - {}\n'.format(disp_and_set[1])
     if len(self.attribute_map) == 0:
-      all_columns += '  - name: |\n'
+      all_columns += '  - Name: |\n'
       all_columns += '      row_item\n'
       settable_list += '  True\n'
     return content.format(var_name=self.var_name, all_columns=all_columns.rstrip('\n'), settable_list=settable_list.rstrip('\n'))
@@ -612,7 +620,7 @@ confirm: True
     content += '    button: |\n'
         
     if self.var_type == 'list': 
-      content += indent_by(bold(self.var_name), 6) + '\n'
+      content += indent_by(bold(self.var_name.capitalize().replace('_', ' ')), 6) + '\n'
       content += indent_by("% for item in {}:".format(self.var_name), 6)
       content += indent_by("* ${ item }", 8)
       content += indent_by("% endfor", 6)
@@ -622,7 +630,7 @@ confirm: True
       content += indent_by(bold(self.var_name), 6) + '\n'
       for att, disp_set in self.attribute_map.items():
         content += indent_by('% if defined("{}.{}"):'.format(self.var_name, disp_set[1]), 6)
-        content += indent_by('* {}: ${{ {}.{} }}'.format(att, self.var_name, disp_set[0]), 6)
+        content += indent_by('* {}: ${{ {}.{} }}'.format(att, self.var_name.capitalize().replace('_', ' '), disp_set[0]), 6)
         content += indent_by('% endif', 6)
       return content.rstrip('\n')
     
@@ -945,7 +953,7 @@ def map_raw_to_final_display(label:str, document_type:str="pdf",
   """For a given set of specific cases, transform a
   PDF field name into a standardized object name
   that will be the value for the attachment field."""
-  if document_type.lower() == "docx":
+  if document_type.lower() == "docx" or '.' in label:
     return label # don't transform DOCX variables
 
   # Turn spaces into `_`, strip non identifier characters
